@@ -5,6 +5,4 @@ def read_pipe_args():
 	parser.add_argument("-p", "--pipeline", dest="pipeline", help="enter the pipeline name")
 	args = vars(parser.parse_args())
 	pipeline = args['pipeline']
-	if (pipeline == None):
-		raise RuntimeError('you must pass the pipeline name')
-	return pipeline
\ No newline at end of file
+	return pipeline
